summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/religion.cc
diff options
context:
space:
mode:
authorDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2009-11-20 00:28:53 -0600
committerDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2009-11-20 00:28:53 -0600
commit38cee7a5098ed1c6e6920df98370128a28df8e06 (patch)
treee8732cdab90ee80ff0cbddfd688c4640a8149654 /crawl-ref/source/religion.cc
parent64eb612845fa71e3e53ae16f26d6a5be2223f172 (diff)
downloadcrawl-ref-38cee7a5098ed1c6e6920df98370128a28df8e06.tar.gz
crawl-ref-38cee7a5098ed1c6e6920df98370128a28df8e06.zip
Fix the last missing instances of the unclean/chaotic split.
Diffstat (limited to 'crawl-ref/source/religion.cc')
-rw-r--r--crawl-ref/source/religion.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/crawl-ref/source/religion.cc b/crawl-ref/source/religion.cc
index 86225c5dd2..ef41b8e9fb 100644
--- a/crawl-ref/source/religion.cc
+++ b/crawl-ref/source/religion.cc
@@ -5013,14 +5013,14 @@ void god_pitch(god_type which_god)
// When you start worshipping a good god, you make all non-hostile
// unholy and evil beings hostile; when you start worshipping Zin,
// you make all non-hostile chaotic beings hostile; and when you
// start worshipping Trog, you make all non-hostile magic users
// hostile.
if (is_good_god(you.religion) && unholy_and_evil_beings_attitude_change())
mpr("Your unholy and evil allies forsake you.", MSGCH_MONSTER_ENCHANT);
- if (you.religion == GOD_ZIN && chaotic_beings_attitude_change())
- mpr("Your chaotic allies forsake you.", MSGCH_MONSTER_ENCHANT);
+ if (you.religion == GOD_ZIN && unclean_and_chaotic_beings_attitude_change())
+ mpr("Your unclean and chaotic allies forsake you.", MSGCH_MONSTER_ENCHANT);
else if (you.religion == GOD_TROG && spellcasters_attitude_change())
mpr("Your magic-using allies forsake you.", MSGCH_MONSTER_ENCHANT);
@@ -5013,14 +5013,14 @@ void god_pitch(god_type which_god)
// When you start worshipping a good god, you make all non-hostile
// unholy and evil beings hostile; when you start worshipping Zin,
- // you make all non-hostile chaotic beings hostile; and when you
- // start worshipping Trog, you make all non-hostile magic users
- // hostile.
+ // you make all non-hostile unclean and chaotic beings hostile; and
+ // when you start worshipping Trog, you make all non-hostile magic
+ // users hostile.
if (is_good_god(you.religion) && unholy_and_evil_beings_attitude_change())
mpr("Your unholy and evil allies forsake you.", MSGCH_MONSTER_ENCHANT);